﻿    <#
    .SYNOPSIS
        The 'PMPAgentInstallationScript' script file installs the PMP Agent in the target machines via the Windows GPO.

    .DESCRIPTION
        The script uses the Windows GPO and the installation key that is provided as the argument to the script to install the agents at the specified location.


    .PARAMETER $args
        Supply the installation key as the argument to the script, which will be used to install the script. Ensure that the installation key is generated with a time limit so that the same key can be used for multiple installations.



    .VARIABLE $AgentZipSource
        This variable represents the network path of the agent installer zip which will be extracted during the installation process.

     .VARIABLE $AgentDestinationPath
        This variable represents the desired installation path in which the agent zip will be extracted and installed. Ensure that the path has the right privileges for the installation.

    .INPUTS
        provide Installationkey in the arguments and network path and installation path as variables

    .OUTPUTS
        The script does not output any data. The PMP Agent service will be up and running in the service console after a successful execution of the script. You can also find the status of the script execution in the event logs.


    .EXAMPLE
        PMPAgentInstallationScript.ps1 b0f2b2d5f2bcb0e7

    
    .NOTES
        Please ensure that the script is disabled in the GPO after the installation to avoid unwanted script execution.

    #>

$AgentZipSource="\\zylker.com \SysVol\zylker.com\Policies\{33A6F6BE-4A9E-4CCA-AB5A-7C96E14F2ACB}\Machine\Scripts\Startup\PMP_WindowsAgent_CS.zip"

$AgentDestinationPath="c:\Program Files"

Copy-Item $AgentZipSource -Destination $AgentDestinationPath

Expand-Archive "$AgentDestinationPath\PMP_WindowsAgent_CS.zip" -DestinationPath $AgentDestinationPath

cd "$AgentDestinationPath\PMP_WindowsAgent_CS\PMPAgent\bin"

./AgentInstaller.exe install $args